@@ -339,6 +339,10 @@ mfxStatus CheckFrameInfoCodecs(mfxFrameInfo  *info, mfxU32 codecId)
                   || info->ChromaFormat == MFX_CHROMAFORMAT_YUV444
                   , MFX_ERR_INVALID_VIDEO_PARAM);
         break;
+    case MFX_CODEC_AV1:
+        MFX_CHECK(info->ChromaFormat == MFX_CHROMAFORMAT_YUV420
+            , MFX_ERR_INVALID_VIDEO_PARAM);
+        break;
     default:
         MFX_CHECK(info->ChromaFormat == MFX_CHROMAFORMAT_YUV420 || info->ChromaFormat == MFX_CHROMAFORMAT_YUV400, MFX_ERR_INVALID_VIDEO_PARAM);
         break;
@@ -1295,6 +1299,7 @@ mfxPlatform MakePlatform(eMFXHWType type, mfxU16 device_id)
                          platform.CodeName = MFX_PLATFORM_BATTLEMAGE;    break;
     // From Pantherlake platform.CodeName will be filled with MFX_PLATFORM_MAXIMUM. NOT to create any new CodeName values.
     case MFX_HW_PTL    : platform.CodeName = MFX_PLATFORM_MAXIMUM;       break;
+    case MFX_HW_NVL_XE3G : platform.CodeName = MFX_PLATFORM_MAXIMUM;     break; 
     default:
                          platform.MediaAdapterType = MFX_MEDIA_UNKNOWN;
                          platform.CodeName = MFX_PLATFORM_UNKNOWN;       break;
